@@ -555,23 +555,35 @@ test_that(
 test_that(
  desc = "same values propagated to pred output with na_action = pass",
  code = {
-  expect_identical(p_cc[obs_expect, ],
-                   p_ps[obs_expect, ])
 
-  expect_identical(p_cc[obs_expect, ],
-                   p_ps_dt[obs_expect, ])
+  expect_equal(p_cc[obs_expect, ],
+               p_ps[obs_expect, ],
+               tolerance = 0.05)
 
-  expect_identical(p_cc[obs_expect, ],
-                   p_ps_tbl[obs_expect, ])
+  expect_equal(p_cc[obs_expect, ],
+               p_ps_dt[obs_expect, ],
+               tolerance = 0.05)
+
+  expect_equal(p_cc[obs_expect, ],
+               p_ps_tbl[obs_expect, ],
+               tolerance = 0.05)
  }
+
 )
 
 test_that(
  desc = "missing values propagated to pred output with na_action = pass",
  code = {
+
   expect_true(all(is.na(p_ps[na_expect, ])))
-  expect_identical(p_ps, p_ps_dt)
-  expect_identical(p_ps, p_ps_tbl)
+
+  expect_equal(p_ps,
+               p_ps_dt,
+               tolerance = 0.05)
+
+  expect_equal(p_ps,
+               p_ps_tbl,
+               tolerance = 0.05)
  }
 )
 
@@ -619,10 +631,19 @@ test_that(
 test_that(
  desc = "missing values propagated to pred output with na_action = pass",
  code = {
+
   expect_true(all(is.na(p_ps[na_expect, ])))
-  expect_identical(p_ps, p_ps_dt)
-  expect_identical(p_ps, p_ps_tbl)
+
+  expect_equal(p_ps,
+               p_ps_dt,
+               tolerance = 0.05)
+
+  expect_equal(p_ps,
+               p_ps_tbl,
+               tolerance = 0.05)
+
  }
+
 )
 
 new_data_all_miss <- new_data_miss
